@@ -27,6 +27,9 @@
 #' \item{se}{Standard error of the estimated treatment effect.}
 #' \item{p.val}{P value of testing the treatment effect based on the efficient influence function of
 #' the restricted mean survival time lost by the end of study.}
+#' \item{coef}{Coefficients of covariates in the working Cox models for the composite event.}
+#' \item{ph}{P values of the proportional hazards assumption in the working Cox models for the composite event.}
+#' \item{cumhaz}{Baseline cumulative hazards in the working Cox models for the composite event.}
 #' }
 #'
 #' @details
@@ -45,8 +48,7 @@
 #'
 #' @seealso \code{\link[tteICE]{surv.composite}}, \code{\link[tteICE]{surv.tteICE}}
 #'
-#'
-#' @export
+#' @keywords internal
 
 surv.composite.eff <- function(A,Time,cstatus,X=NULL){
   n = length(A)
@@ -68,8 +70,9 @@ surv.composite.eff <- function(A,Time,cstatus,X=NULL){
   Xb1c = X%*%fit1c$coefficients
   Xb0c = X%*%fit0c$coefficients
   cumhaz1 = .matchy(c(0,basehaz(fit1,centered=FALSE)$hazard),tt1,tt)
-  cumhaz1 = exp(Xb1)%*%t(cumhaz1)
   cumhaz0 = .matchy(c(0,basehaz(fit0,centered=FALSE)$hazard),tt0,tt)
+  cumhaz = data.frame(time=tt,cumhaz1=cumhaz1,cumhaz0=cumhaz0)
+  cumhaz1 = exp(Xb1)%*%t(cumhaz1)
   cumhaz0 = exp(Xb0)%*%t(cumhaz0)
   cumhaz1c = .matchy(c(0,basehaz(fit1c,centered=FALSE)$hazard),c(0,basehaz(fit1c)$time),tt)
   cumhaz0c = .matchy(c(0,basehaz(fit0c,centered=FALSE)$hazard),c(0,basehaz(fit0c)$time),tt)
@@ -98,6 +101,13 @@ surv.composite.eff <- function(A,Time,cstatus,X=NULL){
   IFt = colSums(t(eif1-eif0)*diff(c(0,tt))*Ti,na.rm=TRUE)
   Vt = sd(IFt,na.rm=TRUE)/sqrt(n)
   p = 2*pnorm(-abs(Tt/Vt))
+  coef1 = fit1$coefficients / attr(X,"scaled:scale")
+  coef0 = fit0$coefficients / attr(X,"scaled:scale")
+  coef = list(coef1=coef1,coef0=coef0)
+  ph1 = cox.zph(fit1, terms=FALSE)
+  ph0 = cox.zph(fit0, terms=FALSE)
+  ph = list(ph1=ph1,ph0=ph0)
   return(list(time1=tt,time0=tt,cif1=cif1,cif0=cif0,se1=se1,se0=se0,
-              time=tt,ate=ate,se=se,p.val=p))
+              time=tt,ate=ate,se=se,p.val=p,
+              coef=coef,ph=ph,cumhaz=cumhaz))
 }
